@@ -1,28 +1,23 @@
 """
 =============
-Font Indexing
+Font indexing
 =============
 
-A little example that shows how the various indexing into the font
-tables relate to one another.  Mainly for mpl developers....
-
+This example shows how the font tables relate to one another.
 """
+
+import os
+
 import matplotlib
-from matplotlib.ft2font import FT2Font, KERNING_DEFAULT, KERNING_UNFITTED, KERNING_UNSCALED
+from matplotlib.ft2font import (
+    FT2Font, KERNING_DEFAULT, KERNING_UNFITTED, KERNING_UNSCALED)
 
 
-fname = matplotlib.get_data_path() + '/fonts/ttf/DejaVuSans.ttf'
-font = FT2Font(fname)
+font = FT2Font(
+    os.path.join(matplotlib.get_data_path(), 'fonts/ttf/DejaVuSans.ttf'))
 font.set_charmap(0)
 
 codes = font.get_charmap().items()
-#dsu = [(ccode, glyphind) for ccode, glyphind in codes]
-#dsu.sort()
-#for ccode, glyphind in dsu:
-#    try: name = font.get_glyph_name(glyphind)
-#    except RuntimeError: pass
-#    else: print('% 4d % 4d %s %s' % (glyphind, ccode, hex(int(ccode)), name))
-
 
 # make a charname to charcode and glyphind dictionary
 coded = {}
@@ -31,6 +26,7 @@ for ccode, glyphind in codes:
     name = font.get_glyph_name(glyphind)
     coded[name] = ccode
     glyphd[name] = glyphind
+    # print(glyphind, ccode, hex(int(ccode)), name)
 
 code = coded['A']
 glyph = font.load_char(code)
@@ -39,4 +35,4 @@ print(glyphd['A'], glyphd['V'], coded['A'], coded['V'])
 print('AV', font.get_kerning(glyphd['A'], glyphd['V'], KERNING_DEFAULT))
 print('AV', font.get_kerning(glyphd['A'], glyphd['V'], KERNING_UNFITTED))
 print('AV', font.get_kerning(glyphd['A'], glyphd['V'], KERNING_UNSCALED))
-print('AV', font.get_kerning(glyphd['A'], glyphd['T'], KERNING_UNSCALED))
+print('AT', font.get_kerning(glyphd['A'], glyphd['T'], KERNING_UNSCALED))
