@@ -11,10 +11,9 @@ import numpy as np
 
 import matplotlib.units as units
 import matplotlib.ticker as ticker
-from matplotlib.cbook import iterable
 
 
-class ProxyDelegate(object):
+class ProxyDelegate:
     def __init__(self, fn_name, proxy_type):
         self.proxy_type = proxy_type
         self.fn_name = fn_name
@@ -26,14 +25,12 @@ class ProxyDelegate(object):
 class TaggedValueMeta(type):
     def __init__(self, name, bases, dict):
         for fn_name in self._proxies:
-            try:
-                dummy = getattr(self, fn_name)
-            except AttributeError:
+            if not hasattr(self, fn_name):
                 setattr(self, fn_name,
                         ProxyDelegate(fn_name, self._proxies[fn_name]))
 
 
-class PassThroughProxy(object):
+class PassThroughProxy:
     def __init__(self, fn_name, obj):
         self.fn_name = fn_name
         self.target = obj.proxy_target
@@ -88,7 +85,7 @@ class ConvertAllProxy(PassThroughProxy):
             if hasattr(a, 'convert_to'):
                 try:
                     a = a.convert_to(self.unit)
-                except:
+                except Exception:
                     pass
                 arg_units.append(a.get_unit())
                 converted_args.append(a.get_value())
@@ -123,15 +120,10 @@ class TaggedValue(metaclass=TaggedValueMeta):
         # generate a new subclass for value
         value_class = type(value)
         try:
-            subcls = type('TaggedValue_of_%s' % (value_class.__name__),
-                          tuple([cls, value_class]),
-                          {})
-            if subcls not in units.registry:
-                units.registry[subcls] = basicConverter
+            subcls = type(f'TaggedValue_of_{value_class.__name__}',
+                          (cls, value_class), {})
             return object.__new__(subcls)
         except TypeError:
-            if cls not in units.registry:
-                units.registry[cls] = basicConverter
             return object.__new__(cls)
 
     def __init__(self, value, unit):
@@ -175,7 +167,10 @@ class TaggedValue(metaclass=TaggedValueMeta):
     def convert_to(self, unit):
         if unit == self.unit or not unit:
             return self
-        new_value = self.unit.convert_value_to(self.value, unit)
+        try:
+            new_value = self.unit.convert_value_to(self.value, unit)
+        except AttributeError:
+            new_value = self
         return TaggedValue(new_value, unit)
 
     def get_value(self):
@@ -185,7 +180,7 @@ class TaggedValue(metaclass=TaggedValueMeta):
         return self.unit
 
 
-class BasicUnit(object):
+class BasicUnit:
     def __init__(self, name, fullname=None):
         self.name = name
         if fullname is None:
@@ -194,7 +189,7 @@ class BasicUnit(object):
         self.conversions = dict()
 
     def __repr__(self):
-        return 'BasicUnit(%s)' % self.name
+        return f'BasicUnit({self.name})'
 
     def __str__(self):
         return self.fullname
@@ -246,7 +241,7 @@ class BasicUnit(object):
         return self
 
 
-class UnitResolver(object):
+class UnitResolver:
     def addition_rule(self, units):
         for unit_1, unit_2 in zip(units[:-1], units[1:]):
             if unit_1 != unit_2:
@@ -312,15 +307,15 @@ def rad_fn(x, pos=None):
     elif n == -2:
         return r'$-\pi$'
     elif n % 2 == 0:
-        return r'$%s\pi$' % (n//2,)
+        return fr'${n//2}\pi$'
     else:
-        return r'$%s\pi/2$' % (n,)
+        return fr'${n}\pi/2$'
 
 
 class BasicUnitConverter(units.ConversionInterface):
     @staticmethod
     def axisinfo(unit, axis):
-        'return AxisInfo instance for x and unit'
+        """Return AxisInfo instance for x and unit."""
 
         if unit == radians:
             return units.AxisInfo(
@@ -345,27 +340,38 @@ class BasicUnitConverter(units.ConversionInterface):
     def convert(val, unit, axis):
         if units.ConversionInterface.is_numlike(val):
             return val
-        if iterable(val):
-            return [thisval.convert_to(unit).get_value() for thisval in val]
+        if np.iterable(val):
+            if isinstance(val, np.ma.MaskedArray):
+                val = val.astype(float).filled(np.nan)
+            out = np.empty(len(val))
+            for i, thisval in enumerate(val):
+                if np.ma.is_masked(thisval):
+                    out[i] = np.nan
+                else:
+                    try:
+                        out[i] = thisval.convert_to(unit).get_value()
+                    except AttributeError:
+                        out[i] = thisval
+            return out
+        if np.ma.is_masked(val):
+            return np.nan
         else:
             return val.convert_to(unit).get_value()
 
     @staticmethod
     def default_units(x, axis):
-        'return the default unit for x or None'
-        if iterable(x):
+        """Return the default unit for x or None."""
+        if np.iterable(x):
             for thisx in x:
                 return thisx.unit
         return x.unit
 
 
 def cos(x):
-    if iterable(x):
+    if np.iterable(x):
         return [math.cos(val.convert_to(radians).get_value()) for val in x]
     else:
         return math.cos(x.convert_to(radians).get_value())
 
 
-basicConverter = BasicUnitConverter()
-units.registry[BasicUnit] = basicConverter
-units.registry[TaggedValue] = basicConverter
+units.registry[BasicUnit] = units.registry[TaggedValue] = BasicUnitConverter()
