@@ -19,7 +19,7 @@ from matplotlib.backend_tools import ToolBase, ToolToggleBase
 
 
 class ListTools(ToolBase):
-    '''List all the tools controlled by the `ToolManager`'''
+    """List all the tools controlled by the `ToolManager`."""
     # keyboard shortcut
     default_keymap = 'm'
     description = 'List Tools'
@@ -45,7 +45,7 @@ class ListTools(ToolBase):
 
 
 class GroupHideTool(ToolToggleBase):
-    '''Show lines with a given gid'''
+    """Show lines with a given gid."""
     default_keymap = 'G'
     description = 'Show by gid'
     default_toggled = True
@@ -61,7 +61,6 @@ class GroupHideTool(ToolToggleBase):
         self.set_lines_visibility(False)
 
     def set_lines_visibility(self, state):
-        gr_lines = []
         for ax in self.figure.get_axes():
             for line in ax.get_lines():
                 if line.get_gid() == self.gid:
